@@ -1,214 +1,214 @@
 use Unicode::Collate::CJK::GB2312;
 +{
-   locale_version => 1.27,
+   locale_version => 1.29,
    overrideCJK => \&Unicode::Collate::CJK::GB2312::weightGB2312,
-   entry => <<'ENTRY', # for DUCET v10.0.0
-0101      ; [.1CAD.001C.0002] # LATIN SMALL LETTER A WITH MACRON
-0061 0304 ; [.1CAD.001C.0002] # LATIN SMALL LETTER A WITH MACRON
-0100      ; [.1CAD.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
-0041 0304 ; [.1CAD.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
-00E1      ; [.1CAD.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-0061 0301 ; [.1CAD.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-0061 0341 ; [.1CAD.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
-00C1      ; [.1CAD.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-0041 0301 ; [.1CAD.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-0041 0341 ; [.1CAD.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
-01CE      ; [.1CAD.001E.0002] # LATIN SMALL LETTER A WITH CARON
-0061 030C ; [.1CAD.001E.0002] # LATIN SMALL LETTER A WITH CARON
-01CD      ; [.1CAD.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
-0041 030C ; [.1CAD.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
-00E0      ; [.1CAD.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-0061 0300 ; [.1CAD.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-0061 0340 ; [.1CAD.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
-00C0      ; [.1CAD.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0041 0300 ; [.1CAD.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0041 0340 ; [.1CAD.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
-0113      ; [.1D10.001C.0002] # LATIN SMALL LETTER E WITH MACRON
-0065 0304 ; [.1D10.001C.0002] # LATIN SMALL LETTER E WITH MACRON
-0112      ; [.1D10.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
-0045 0304 ; [.1D10.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
-00E9      ; [.1D10.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-0065 0301 ; [.1D10.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-0065 0341 ; [.1D10.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
-00C9      ; [.1D10.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-0045 0301 ; [.1D10.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-0045 0341 ; [.1D10.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
-011B      ; [.1D10.001E.0002] # LATIN SMALL LETTER E WITH CARON
-0065 030C ; [.1D10.001E.0002] # LATIN SMALL LETTER E WITH CARON
-011A      ; [.1D10.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
-0045 030C ; [.1D10.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
-00E8      ; [.1D10.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-0065 0300 ; [.1D10.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-0065 0340 ; [.1D10.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
-00C8      ; [.1D10.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-0045 0300 ; [.1D10.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-0045 0340 ; [.1D10.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
-00EA 0304 ; [.1D10.0021.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
-00CA 0304 ; [.1D10.0021.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
-0065 0302 0304 ; [.1D10.0021.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
-0045 0302 0304 ; [.1D10.0021.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
-1EBF      ; [.1D10.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-0065 0302 0301 ; [.1D10.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-0065 0302 0341 ; [.1D10.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
-1EBE      ; [.1D10.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-0045 0302 0301 ; [.1D10.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-0045 0302 0341 ; [.1D10.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
-00EA 0301 ; [.1D10.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
-00EA 0341 ; [.1D10.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
-00CA 0301 ; [.1D10.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
-00CA 0341 ; [.1D10.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
-00EA 030C ; [.1D10.0023.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
-00CA 030C ; [.1D10.0023.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
-0065 0302 030C ; [.1D10.0023.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
-0045 0302 030C ; [.1D10.0023.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
-1EC1      ; [.1D10.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-0065 0302 0300 ; [.1D10.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-0065 0302 0340 ; [.1D10.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
-1EC0      ; [.1D10.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-0045 0302 0300 ; [.1D10.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-0045 0302 0340 ; [.1D10.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
-00EA 0300 ; [.1D10.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
-00EA 0340 ; [.1D10.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
-00CA 0300 ; [.1D10.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
-00CA 0340 ; [.1D10.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
-00EA      ; [.1D10.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
-0065 0302 ; [.1D10.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
-00CA      ; [.1D10.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-0045 0302 ; [.1D10.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-1EC5      ; [.1D10.0025.0002][.0000.002D.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
-1EC4      ; [.1D10.0025.0008][.0000.002D.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
-1EC3      ; [.1D10.0025.0002][.0000.003B.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
-1EC2      ; [.1D10.0025.0008][.0000.003B.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
-1EC7      ; [.1D10.0025.0002][.0000.0042.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
-1EC6      ; [.1D10.0025.0008][.0000.0042.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
-012B      ; [.1D98.001C.0002] # LATIN SMALL LETTER I WITH MACRON
-0069 0304 ; [.1D98.001C.0002] # LATIN SMALL LETTER I WITH MACRON
-012A      ; [.1D98.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
-0049 0304 ; [.1D98.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
-00ED      ; [.1D98.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-0069 0301 ; [.1D98.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-0069 0341 ; [.1D98.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
-00CD      ; [.1D98.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-0049 0301 ; [.1D98.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-0049 0341 ; [.1D98.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
-01D0      ; [.1D98.001E.0002] # LATIN SMALL LETTER I WITH CARON
-0069 030C ; [.1D98.001E.0002] # LATIN SMALL LETTER I WITH CARON
-01CF      ; [.1D98.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
-0049 030C ; [.1D98.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
-00EC      ; [.1D98.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-0069 0300 ; [.1D98.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-0069 0340 ; [.1D98.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
-00CC      ; [.1D98.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-0049 0300 ; [.1D98.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-0049 0340 ; [.1D98.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
-006D 0304 ; [.1E10.001C.0002] # <LATIN SMALL LETTER M, COMBINING MACRON>
-004D 0304 ; [.1E10.001C.0008] # <LATIN CAPITAL LETTER M, COMBINING MACRON>
-1E3F      ; [.1E10.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-006D 0301 ; [.1E10.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-006D 0341 ; [.1E10.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
-1E3E      ; [.1E10.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-004D 0301 ; [.1E10.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-004D 0341 ; [.1E10.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
-006D 030C ; [.1E10.001E.0002] # <LATIN SMALL LETTER M, COMBINING CARON>
-004D 030C ; [.1E10.001E.0008] # <LATIN CAPITAL LETTER M, COMBINING CARON>
-006D 0300 ; [.1E10.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE ACCENT>
-006D 0340 ; [.1E10.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE TONE MARK>
-004D 0300 ; [.1E10.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE ACCENT>
-004D 0340 ; [.1E10.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE TONE MARK>
-006E 0304 ; [.1E1F.001C.0002] # <LATIN SMALL LETTER N, COMBINING MACRON>
-004E 0304 ; [.1E1F.001C.0008] # <LATIN CAPITAL LETTER N, COMBINING MACRON>
-0144      ; [.1E1F.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-006E 0301 ; [.1E1F.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-006E 0341 ; [.1E1F.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
-0143      ; [.1E1F.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-004E 0301 ; [.1E1F.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-004E 0341 ; [.1E1F.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
-0148      ; [.1E1F.001E.0002] # LATIN SMALL LETTER N WITH CARON
-006E 030C ; [.1E1F.001E.0002] # LATIN SMALL LETTER N WITH CARON
-0147      ; [.1E1F.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
-004E 030C ; [.1E1F.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
-01F9      ; [.1E1F.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-006E 0300 ; [.1E1F.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-006E 0340 ; [.1E1F.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
-01F8      ; [.1E1F.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-004E 0300 ; [.1E1F.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-004E 0340 ; [.1E1F.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
-014D      ; [.1E43.001C.0002] # LATIN SMALL LETTER O WITH MACRON
-006F 0304 ; [.1E43.001C.0002] # LATIN SMALL LETTER O WITH MACRON
-014C      ; [.1E43.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
-004F 0304 ; [.1E43.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
-00F3      ; [.1E43.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-006F 0301 ; [.1E43.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-006F 0341 ; [.1E43.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
-00D3      ; [.1E43.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-004F 0301 ; [.1E43.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-004F 0341 ; [.1E43.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
-01D2      ; [.1E43.001E.0002] # LATIN SMALL LETTER O WITH CARON
-006F 030C ; [.1E43.001E.0002] # LATIN SMALL LETTER O WITH CARON
-01D1      ; [.1E43.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
-004F 030C ; [.1E43.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
-00F2      ; [.1E43.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-006F 0300 ; [.1E43.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-006F 0340 ; [.1E43.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
-00D2      ; [.1E43.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-004F 0300 ; [.1E43.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-004F 0340 ; [.1E43.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
-016B      ; [.1F1B.001C.0002] # LATIN SMALL LETTER U WITH MACRON
-0075 0304 ; [.1F1B.001C.0002] # LATIN SMALL LETTER U WITH MACRON
-016A      ; [.1F1B.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
-0055 0304 ; [.1F1B.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
-00FA      ; [.1F1B.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-0075 0301 ; [.1F1B.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-0075 0341 ; [.1F1B.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
-00DA      ; [.1F1B.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-0055 0301 ; [.1F1B.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-0055 0341 ; [.1F1B.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
-01D4      ; [.1F1B.001E.0002] # LATIN SMALL LETTER U WITH CARON
-0075 030C ; [.1F1B.001E.0002] # LATIN SMALL LETTER U WITH CARON
-01D3      ; [.1F1B.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
-0055 030C ; [.1F1B.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
-00F9      ; [.1F1B.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-0075 0300 ; [.1F1B.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-0075 0340 ; [.1F1B.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
-00D9      ; [.1F1B.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-0055 0300 ; [.1F1B.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-0055 0340 ; [.1F1B.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
-01D6      ; [.1F1B.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
-0075 0308 0304 ; [.1F1B.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
-01D5      ; [.1F1B.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
-0055 0308 0304 ; [.1F1B.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
-00FC 0304 ; [.1F1B.0021.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING MACRON>
-00DC 0304 ; [.1F1B.0021.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING MACRON>
-01D8      ; [.1F1B.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-0075 0308 0301 ; [.1F1B.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-0075 0308 0341 ; [.1F1B.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
-01D7      ; [.1F1B.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-0055 0308 0301 ; [.1F1B.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-0055 0308 0341 ; [.1F1B.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
-00FC 0301 ; [.1F1B.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
-00FC 0341 ; [.1F1B.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
-00DC 0301 ; [.1F1B.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
-00DC 0341 ; [.1F1B.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
-01DA      ; [.1F1B.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
-0075 0308 030C ; [.1F1B.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
-01D9      ; [.1F1B.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
-0055 0308 030C ; [.1F1B.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
-00FC 030C ; [.1F1B.0023.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING CARON>
-00DC 030C ; [.1F1B.0023.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING CARON>
-01DC      ; [.1F1B.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-0075 0308 0300 ; [.1F1B.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-0075 0308 0340 ; [.1F1B.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
-01DB      ; [.1F1B.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-0055 0308 0300 ; [.1F1B.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-0055 0308 0340 ; [.1F1B.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
-00FC 0300 ; [.1F1B.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
-00FC 0340 ; [.1F1B.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
-00DC 0300 ; [.1F1B.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
-00DC 0340 ; [.1F1B.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
-00FC      ; [.1F1B.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-0075 0308 ; [.1F1B.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
-00DC      ; [.1F1B.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
-0055 0308 ; [.1F1B.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
+   entry => <<'ENTRY', # for DUCET v13.0.0
+0101      ; [.1FA2.001C.0002] # LATIN SMALL LETTER A WITH MACRON
+0061 0304 ; [.1FA2.001C.0002] # LATIN SMALL LETTER A WITH MACRON
+0100      ; [.1FA2.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
+0041 0304 ; [.1FA2.001C.0008] # LATIN CAPITAL LETTER A WITH MACRON
+00E1      ; [.1FA2.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+0061 0301 ; [.1FA2.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+0061 0341 ; [.1FA2.001D.0002] # LATIN SMALL LETTER A WITH ACUTE
+00C1      ; [.1FA2.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+0041 0301 ; [.1FA2.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+0041 0341 ; [.1FA2.001D.0008] # LATIN CAPITAL LETTER A WITH ACUTE
+01CE      ; [.1FA2.001E.0002] # LATIN SMALL LETTER A WITH CARON
+0061 030C ; [.1FA2.001E.0002] # LATIN SMALL LETTER A WITH CARON
+01CD      ; [.1FA2.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
+0041 030C ; [.1FA2.001E.0008] # LATIN CAPITAL LETTER A WITH CARON
+00E0      ; [.1FA2.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+0061 0300 ; [.1FA2.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+0061 0340 ; [.1FA2.001F.0002] # LATIN SMALL LETTER A WITH GRAVE
+00C0      ; [.1FA2.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0041 0300 ; [.1FA2.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0041 0340 ; [.1FA2.001F.0008] # LATIN CAPITAL LETTER A WITH GRAVE
+0113      ; [.2007.001C.0002] # LATIN SMALL LETTER E WITH MACRON
+0065 0304 ; [.2007.001C.0002] # LATIN SMALL LETTER E WITH MACRON
+0112      ; [.2007.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
+0045 0304 ; [.2007.001C.0008] # LATIN CAPITAL LETTER E WITH MACRON
+00E9      ; [.2007.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+0065 0301 ; [.2007.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+0065 0341 ; [.2007.001D.0002] # LATIN SMALL LETTER E WITH ACUTE
+00C9      ; [.2007.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+0045 0301 ; [.2007.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+0045 0341 ; [.2007.001D.0008] # LATIN CAPITAL LETTER E WITH ACUTE
+011B      ; [.2007.001E.0002] # LATIN SMALL LETTER E WITH CARON
+0065 030C ; [.2007.001E.0002] # LATIN SMALL LETTER E WITH CARON
+011A      ; [.2007.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
+0045 030C ; [.2007.001E.0008] # LATIN CAPITAL LETTER E WITH CARON
+00E8      ; [.2007.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+0065 0300 ; [.2007.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+0065 0340 ; [.2007.001F.0002] # LATIN SMALL LETTER E WITH GRAVE
+00C8      ; [.2007.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+0045 0300 ; [.2007.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+0045 0340 ; [.2007.001F.0008] # LATIN CAPITAL LETTER E WITH GRAVE
+00EA 0304 ; [.2007.0021.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
+00CA 0304 ; [.2007.0021.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING MACRON>
+0065 0302 0304 ; [.2007.0021.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
+0045 0302 0304 ; [.2007.0021.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING MACRON>
+1EBF      ; [.2007.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+0065 0302 0301 ; [.2007.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+0065 0302 0341 ; [.2007.0022.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
+1EBE      ; [.2007.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+0045 0302 0301 ; [.2007.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+0045 0302 0341 ; [.2007.0022.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
+00EA 0301 ; [.2007.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
+00EA 0341 ; [.2007.0022.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
+00CA 0301 ; [.2007.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE ACCENT>
+00CA 0341 ; [.2007.0022.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING ACUTE TONE MARK>
+00EA 030C ; [.2007.0023.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
+00CA 030C ; [.2007.0023.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING CARON>
+0065 0302 030C ; [.2007.0023.0002] # <LATIN SMALL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
+0045 0302 030C ; [.2007.0023.0008] # <LATIN CAPITAL LETTER E, COMBINING CIRCUMFLEX ACCENT, COMBINING CARON>
+1EC1      ; [.2007.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+0065 0302 0300 ; [.2007.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+0065 0302 0340 ; [.2007.0024.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
+1EC0      ; [.2007.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+0045 0302 0300 ; [.2007.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+0045 0302 0340 ; [.2007.0024.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
+00EA 0300 ; [.2007.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
+00EA 0340 ; [.2007.0024.0002] # <LATIN SMALL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
+00CA 0300 ; [.2007.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE ACCENT>
+00CA 0340 ; [.2007.0024.0008] # <LATIN CAPITAL LETTER E WITH CIRCUMFLEX, COMBINING GRAVE TONE MARK>
+00EA      ; [.2007.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
+0065 0302 ; [.2007.0025.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX
+00CA      ; [.2007.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+0045 0302 ; [.2007.0025.0008] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+1EC5      ; [.2007.0025.0002][.0000.002D.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
+1EC4      ; [.2007.0025.0008][.0000.002D.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
+1EC3      ; [.2007.0025.0002][.0000.003B.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
+1EC2      ; [.2007.0025.0008][.0000.003B.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
+1EC7      ; [.2007.0025.0002][.0000.0042.0002] # LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
+1EC6      ; [.2007.0025.0008][.0000.0042.0002] # LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
+012B      ; [.2090.001C.0002] # LATIN SMALL LETTER I WITH MACRON
+0069 0304 ; [.2090.001C.0002] # LATIN SMALL LETTER I WITH MACRON
+012A      ; [.2090.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
+0049 0304 ; [.2090.001C.0008] # LATIN CAPITAL LETTER I WITH MACRON
+00ED      ; [.2090.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+0069 0301 ; [.2090.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+0069 0341 ; [.2090.001D.0002] # LATIN SMALL LETTER I WITH ACUTE
+00CD      ; [.2090.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+0049 0301 ; [.2090.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+0049 0341 ; [.2090.001D.0008] # LATIN CAPITAL LETTER I WITH ACUTE
+01D0      ; [.2090.001E.0002] # LATIN SMALL LETTER I WITH CARON
+0069 030C ; [.2090.001E.0002] # LATIN SMALL LETTER I WITH CARON
+01CF      ; [.2090.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
+0049 030C ; [.2090.001E.0008] # LATIN CAPITAL LETTER I WITH CARON
+00EC      ; [.2090.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+0069 0300 ; [.2090.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+0069 0340 ; [.2090.001F.0002] # LATIN SMALL LETTER I WITH GRAVE
+00CC      ; [.2090.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+0049 0300 ; [.2090.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+0049 0340 ; [.2090.001F.0008] # LATIN CAPITAL LETTER I WITH GRAVE
+006D 0304 ; [.2109.001C.0002] # <LATIN SMALL LETTER M, COMBINING MACRON>
+004D 0304 ; [.2109.001C.0008] # <LATIN CAPITAL LETTER M, COMBINING MACRON>
+1E3F      ; [.2109.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+006D 0301 ; [.2109.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+006D 0341 ; [.2109.001D.0002] # LATIN SMALL LETTER M WITH ACUTE
+1E3E      ; [.2109.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+004D 0301 ; [.2109.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+004D 0341 ; [.2109.001D.0008] # LATIN CAPITAL LETTER M WITH ACUTE
+006D 030C ; [.2109.001E.0002] # <LATIN SMALL LETTER M, COMBINING CARON>
+004D 030C ; [.2109.001E.0008] # <LATIN CAPITAL LETTER M, COMBINING CARON>
+006D 0300 ; [.2109.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE ACCENT>
+006D 0340 ; [.2109.001F.0002] # <LATIN SMALL LETTER M, COMBINING GRAVE TONE MARK>
+004D 0300 ; [.2109.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE ACCENT>
+004D 0340 ; [.2109.001F.0008] # <LATIN CAPITAL LETTER M, COMBINING GRAVE TONE MARK>
+006E 0304 ; [.2118.001C.0002] # <LATIN SMALL LETTER N, COMBINING MACRON>
+004E 0304 ; [.2118.001C.0008] # <LATIN CAPITAL LETTER N, COMBINING MACRON>
+0144      ; [.2118.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+006E 0301 ; [.2118.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+006E 0341 ; [.2118.001D.0002] # LATIN SMALL LETTER N WITH ACUTE
+0143      ; [.2118.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+004E 0301 ; [.2118.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+004E 0341 ; [.2118.001D.0008] # LATIN CAPITAL LETTER N WITH ACUTE
+0148      ; [.2118.001E.0002] # LATIN SMALL LETTER N WITH CARON
+006E 030C ; [.2118.001E.0002] # LATIN SMALL LETTER N WITH CARON
+0147      ; [.2118.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
+004E 030C ; [.2118.001E.0008] # LATIN CAPITAL LETTER N WITH CARON
+01F9      ; [.2118.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+006E 0300 ; [.2118.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+006E 0340 ; [.2118.001F.0002] # LATIN SMALL LETTER N WITH GRAVE
+01F8      ; [.2118.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+004E 0300 ; [.2118.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+004E 0340 ; [.2118.001F.0008] # LATIN CAPITAL LETTER N WITH GRAVE
+014D      ; [.213C.001C.0002] # LATIN SMALL LETTER O WITH MACRON
+006F 0304 ; [.213C.001C.0002] # LATIN SMALL LETTER O WITH MACRON
+014C      ; [.213C.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
+004F 0304 ; [.213C.001C.0008] # LATIN CAPITAL LETTER O WITH MACRON
+00F3      ; [.213C.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+006F 0301 ; [.213C.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+006F 0341 ; [.213C.001D.0002] # LATIN SMALL LETTER O WITH ACUTE
+00D3      ; [.213C.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+004F 0301 ; [.213C.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+004F 0341 ; [.213C.001D.0008] # LATIN CAPITAL LETTER O WITH ACUTE
+01D2      ; [.213C.001E.0002] # LATIN SMALL LETTER O WITH CARON
+006F 030C ; [.213C.001E.0002] # LATIN SMALL LETTER O WITH CARON
+01D1      ; [.213C.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
+004F 030C ; [.213C.001E.0008] # LATIN CAPITAL LETTER O WITH CARON
+00F2      ; [.213C.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+006F 0300 ; [.213C.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+006F 0340 ; [.213C.001F.0002] # LATIN SMALL LETTER O WITH GRAVE
+00D2      ; [.213C.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+004F 0300 ; [.213C.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+004F 0340 ; [.213C.001F.0008] # LATIN CAPITAL LETTER O WITH GRAVE
+016B      ; [.2217.001C.0002] # LATIN SMALL LETTER U WITH MACRON
+0075 0304 ; [.2217.001C.0002] # LATIN SMALL LETTER U WITH MACRON
+016A      ; [.2217.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
+0055 0304 ; [.2217.001C.0008] # LATIN CAPITAL LETTER U WITH MACRON
+00FA      ; [.2217.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+0075 0301 ; [.2217.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+0075 0341 ; [.2217.001D.0002] # LATIN SMALL LETTER U WITH ACUTE
+00DA      ; [.2217.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+0055 0301 ; [.2217.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+0055 0341 ; [.2217.001D.0008] # LATIN CAPITAL LETTER U WITH ACUTE
+01D4      ; [.2217.001E.0002] # LATIN SMALL LETTER U WITH CARON
+0075 030C ; [.2217.001E.0002] # LATIN SMALL LETTER U WITH CARON
+01D3      ; [.2217.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
+0055 030C ; [.2217.001E.0008] # LATIN CAPITAL LETTER U WITH CARON
+00F9      ; [.2217.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+0075 0300 ; [.2217.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+0075 0340 ; [.2217.001F.0002] # LATIN SMALL LETTER U WITH GRAVE
+00D9      ; [.2217.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+0055 0300 ; [.2217.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+0055 0340 ; [.2217.001F.0008] # LATIN CAPITAL LETTER U WITH GRAVE
+01D6      ; [.2217.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
+0075 0308 0304 ; [.2217.0021.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
+01D5      ; [.2217.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
+0055 0308 0304 ; [.2217.0021.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
+00FC 0304 ; [.2217.0021.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING MACRON>
+00DC 0304 ; [.2217.0021.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING MACRON>
+01D8      ; [.2217.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+0075 0308 0301 ; [.2217.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+0075 0308 0341 ; [.2217.0022.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
+01D7      ; [.2217.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+0055 0308 0301 ; [.2217.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+0055 0308 0341 ; [.2217.0022.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
+00FC 0301 ; [.2217.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
+00FC 0341 ; [.2217.0022.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
+00DC 0301 ; [.2217.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE ACCENT>
+00DC 0341 ; [.2217.0022.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING ACUTE TONE MARK>
+01DA      ; [.2217.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
+0075 0308 030C ; [.2217.0023.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND CARON
+01D9      ; [.2217.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
+0055 0308 030C ; [.2217.0023.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
+00FC 030C ; [.2217.0023.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING CARON>
+00DC 030C ; [.2217.0023.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING CARON>
+01DC      ; [.2217.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+0075 0308 0300 ; [.2217.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+0075 0308 0340 ; [.2217.0024.0002] # LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
+01DB      ; [.2217.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+0055 0308 0300 ; [.2217.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+0055 0308 0340 ; [.2217.0024.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
+00FC 0300 ; [.2217.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
+00FC 0340 ; [.2217.0024.0002] # <LATIN SMALL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
+00DC 0300 ; [.2217.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE ACCENT>
+00DC 0340 ; [.2217.0024.0008] # <LATIN CAPITAL LETTER U WITH DIAERESIS, COMBINING GRAVE TONE MARK>
+00FC      ; [.2217.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
+0075 0308 ; [.2217.0025.0002] # LATIN SMALL LETTER U WITH DIAERESIS
+00DC      ; [.2217.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
+0055 0308 ; [.2217.0025.0008] # LATIN CAPITAL LETTER U WITH DIAERESIS
 E2D8      ; [.8EAB.0020.0002] # <unknown>
 E2D9      ; [.8EAC.0020.0002] # <unknown>
 E2DA      ; [.8EAD.0020.0002] # <unknown>
